==> haskell-uuid-1.3.13-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.13
id: uuid-1.3.13-3xFQCcgZw7p3MXCp6Sxx1s
key: uuid-1.3.13-3xFQCcgZw7p3MXCp6Sxx1s
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    .
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
abi: 20cbf4b7117ead3e8427b56cadf97f2b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-1.3.13
library-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-1.3.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/uuid-1.3.13
hs-libraries: HSuuid-1.3.13-3xFQCcgZw7p3MXCp6Sxx1s
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    cryptohash-sha1-0.11.100.1-FDvrYQWYZ3OJapXcOd3Cpn
    cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
    entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    network-info-0.2.0.9-6XOYxvXysNh3PriqzjD5Zu
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We time-1.8.0.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    uuid-types-1.0.3-C70jVBzardLFMfav9eGqfw
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cryptohash-sha1-0.11.100.1-FDvrYQWYZ3OJapXcOd3Cpn=8b13e0a1d1c830084dab12aabbcd68a4
             cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY=60e06478e748fb839d45cecac76e5b66
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=a6112742140c3bfa625711e5fba8dc1f
             network-info-0.2.0.9-6XOYxvXysNh3PriqzjD5Zu=8957b381a8887def9a25278ac0eff1f3
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             uuid-types-1.0.3-C70jVBzardLFMfav9eGqfw=c8c92b90f840b05e255cb21231f7b398
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.13-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.13
id: uuid-1.3.13-BTxHnfGbfLz22CSMJVtnA5
key: uuid-1.3.13-BTxHnfGbfLz22CSMJVtnA5
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    .
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
abi: 87bd49eb150855fdce59e6e4bfd32fdc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-1.3.13
library-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-1.3.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/uuid-1.3.13
hs-libraries: HSuuid-1.3.13-BTxHnfGbfLz22CSMJVtnA5
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    cryptohash-sha1-0.11.100.1-FDvrYQWYZ3OJapXcOd3Cpn
    cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
    entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    network-info-0.2.0.9-6XOYxvXysNh3PriqzjD5Zu
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We time-1.8.0.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    uuid-types-1.0.3-C31qoQYhIFY6Z1J9cF82aJ
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cryptohash-sha1-0.11.100.1-FDvrYQWYZ3OJapXcOd3Cpn=8b13e0a1d1c830084dab12aabbcd68a4
             cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY=60e06478e748fb839d45cecac76e5b66
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=a6112742140c3bfa625711e5fba8dc1f
             network-info-0.2.0.9-6XOYxvXysNh3PriqzjD5Zu=8957b381a8887def9a25278ac0eff1f3
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             uuid-types-1.0.3-C31qoQYhIFY6Z1J9cF82aJ=d68dd3e81b591d25ec1c31d8117f2262
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
